@@ -25,7 +25,7 @@
 
 __authors__ = ["V. Valls"]
 __license__ = "MIT"
-__date__ = "26/06/2023"
+__date__ = "05/09/2023"
 
 import logging
 import numpy
@@ -186,7 +186,7 @@ class _PeakSelectionTableView(qt.QTableView):
     def __onRowInserted(self, parent, start, end):
         self.__openPersistantViewOnRowInserted(parent, start, end)
         self.updateGeometry()
-        # It have to be done only on the 3, else the layout is wrong
+        # It has to be done only on the 3, else the layout is wrong
         self.resizeColumnToContents(_PeakSelectionTableModel.ColumnControl)
 
     def __openPersistantViewOnRowInserted(self, parent, start, end):
@@ -792,7 +792,7 @@ class _RingSelectionBehaviour(qt.QObject):
             of the table view
     - Else
         - The spinner is enabled
-        - The value of the spinner have to be consistant with the hilighted
+        - The value of the spinner has to be consistant with the hilighted
             ring from the table view.
     """
 
@@ -932,7 +932,7 @@ class _RingSelectionBehaviour(qt.QObject):
             peak = model.peakObject(index)
 
         if not self.__newRingOption.isChecked():
-            # It have to be updated
+            # It has to be updated
             if peak is not None:
                 self.__spinnerRing.valueChanged.disconnect(self.__spinerRingChanged)
                 try:
